/**
  ******************************************************************************
  * @file    ys32f030_crc.h
  * @author  YSPRING Application Team
  * @version V1.0.1
  * @date    2023.6.14
  * @brief   This file contains all the functions prototypes for the CRC firmware 
  *          library.
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __YS32F030_CRC_H
#define __YS32F030_CRC_H

#ifdef __cplusplus
 extern "C" {
#endif

/*!< Includes ----------------------------------------------------------------*/
#include "ys32f030.h"

/** @addtogroup YS32F030_StdPeriph_Driver
  * @{
  */

/** @addtogroup CRC
  * @{
  */
 #define CRC_Result_Reset   (0xFFFFFFFFU)    
/** @defgroup CRC_FLAG
  * @{
  */
#define CRC_FLAG           (CRC_SR_FLAG)
#define IS_CRC_FLAG(FLAG)  ((FLAG) == CRC_FLAG)

/**
  * @}
  */

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

/* CRC computation ************************************************************/
void CRC_DeInit(void);
void CRC_CalibCRC(uint32_t CRC_Data);
void CRC_ResetCRCCalculationUnit(void);
uint32_t CRC_CalcCRC(uint32_t CRC_Data);
uint32_t CRC_CalcBlockCRC(uint32_t pBuffer[], uint32_t BufferLength);
uint32_t CRC_CalcBlockCRC16bits(uint16_t *InData, uint32_t BufferLength);
uint32_t CRC_CalcBlockCRC8bits(uint8_t *InData, uint32_t BufferLength);
uint32_t CRC_GetCRC(void);
FlagStatus CRC_GetFlagStatus(uint16_t FLAG);

#ifdef __cplusplus
}
#endif

#endif /* __YS32F030_CRC_H */

/**
  * @}
  */

/**
  * @}
  */

